==> mall-center-api-0.1.11-20211123.094957-21-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/groupbuy/GroupBuyCreateParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.groupbuy;

import java.io.Serializable;

/**
 * @Date 2021/11/18 4:53 下午
 * @Created by cmm
 */
public class GroupBuyCreateParam implements Serializable {
    private static final long serialVersionUID = 5955141483091905179L;

    private Long appId;

    private Long actId;

    private Long groupId;

    private Long appItemId;

    private Long skuId;

    private Long consumerId;

    /**
     * 原价 单位分
     */
    private Long originalPrice;

    public Long getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Long originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }
}

==> mall-center-api-0.1.33-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/groupbuy/GroupBuyCreateParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.groupbuy;

import java.io.Serializable;

/**
 * @Date 2021/11/18 4:53 下午
 * @Created by cmm
 */
public class GroupBuyCreateParam implements Serializable {
    private static final long serialVersionUID = 5955141483091905179L;

    private Long appId;

    private Long actId;

    private Long groupId;

    private Long appItemId;

    private Long skuId;

    private Long consumerId;

    /**
     * 原价 单位分
     */
    private Long originalPrice;
    /**
     * 原积分
     */
    private Long originalCredits;

    public Long getOriginalCredits() {
        return originalCredits;
    }

    public void setOriginalCredits(Long originalCredits) {
        this.originalCredits = originalCredits;
    }

    public Long getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Long originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }
}
